"use client"

import { useForm } from "react-hook-form";
import Code from "@/components/Code";
import Container from "@/components/Container";
import Text from "@/components/Text";
import MenuItems from "@/utils/menuItems";
import Checkbox from "@/components/Checkbox";
import Form from "@/components/Form";
import FormGroup from "@/components/FormGroup";
import FormItem from "@/components/FormItem";
import Button from "@/components/Button";
import { useState } from "react";

export default function CheckboxPage() {
  const {
    control,
    handleSubmit,
    formState: { errors },
  } = useForm({defaultValue:{termos:true,},});


  const radioNums = [
    {id: 1, label:"Opção 1", value:"opcao1", radioName:"opcao", defaultChecked:false},
    {id: 2, label:"Opção 2", value:"opcao2", radioName:"opcao", defaultChecked:true},
    {id: 3, label:"Opção 3", value:"opcao3", radioName:"opcao", defaultChecked:false},
    {id: 4, label:"Opção 4", value:"opcao4", radioName:"opcao", defaultChecked:false},
  ]

  const onSubmit = (data) => {
    console.log(data);
  };

  const [checked, setIsChecked] = useState(false);

  return (
    <Container flexDirection="row">
      <MenuItems />
      <Container margin="1rem" flexGrow="1">
        {/* Seção principal */}
        <Text as="h1" margin="0" onClick={()=>console.log(checked)}>
          Componente Checkbox
        </Text>
        <Text as="p" margin="1rem 0">
          O componente Checkbox permite ao usuário múltipla seleção. Por padrão,
          utilza a cor primária definida no tema. Tem css valid e invalid.<br/>
          Use o parametro exportValue para exportar o estado.
        </Text>
        <Container style={{ border: "1px solid black" }} padding=".5rem">
          <form>
          <Checkbox label="Concordo com os termos" required big exportValue={setIsChecked}/>
          <Checkbox label="Concordo com os termos" marginTop={10} disabled/>
          <Checkbox label="Concordo com os termos" checked marginTop={10} small />
          <Button>Enviar</Button>
          </form>
        </Container>
        <Container
          style={{
            border: "1px solid black",
            borderTop: "0",
            backgroundColor: "#f5f2f0",
          }}
        >
          <Code language="javascript">
            {`import Checkbox from "@/components/Checkbox";

<form>
<Checkbox label="Concordo com os termos" required big exportValue={setIsChecked}/>
<Checkbox label="Concordo com os termos"  marginTop={10} disabled/>
<Checkbox label="Concordo com os termos"  checked marginTop={10} small />
<Button>batata</Button>
</form>`}
          </Code>
        </Container>

        {/* Seção customização */}
        <Text as="h2" margin="0" margin_top="1rem">
          Customização
        </Text>
        <Text as="p" margin="1rem 0">
          Também é possível customizar o componente Checkbox utilizando a
          propriedade style.
        </Text>
        <Container style={{ border: "1px solid black" }} padding=".5rem">
          <Checkbox
            label="Concordo com os termos"
            marginTop="1rem"
            marginLeft="1rem"
            
          />
        </Container>
        <Container
          style={{
            border: "1px solid black",
            borderTop: "0",
            backgroundColor: "#f5f2f0",
          }}
        >
          <Code language="javascript">
            {`import Checkbox from "@/components/Checkbox";

<Checkbox label="Concordo com os termos" marginTop="1rem" marginLeft="1rem" />`}
          </Code>
        </Container>
        <Text as="p" margin="1rem 0">
          As seguintes propridades podem ser informadas como parâmetro:
        </Text>
        <Container style={{flexDirection: "row"}} marginBottom={25}>
        <ul style={{ marginLeft: '1rem', lineHeight: '2',}}>
          <li>margin</li>
          <li>marginTop</li>
          <li>marginRight</li>
          <li>marginBottom</li>
          <li>marginLeft</li>
        </ul>
        <ul style={{ marginLeft: '3rem', lineHeight: '2',}}>
          <li>padding</li>
          <li>paddingTop</li>
          <li>paddingRight</li>
          <li>paddingBottom</li>
          <li>paddingLeft</li>  
        </ul>
        <ul style={{ marginLeft: '3rem', lineHeight: '2',}}>
          <li>style</li>
          <li>big</li>
          <li>small</li>
          <li>disabled</li>
        </ul> 
        </Container>


        {/* Seção React Hook Form */}
        <Text as="h2" margin="0" margin_top="1rem">
          Compatibilidade com React Hook Form
        </Text>
        <Text as="p" margin="1rem 0">
          O componente Input é compatível com o React Hook Form. Pressione enter
          no input para visualizar a validação. Também tem css valid e invalid.
        </Text>
        <Container style={{ border: "1px solid black" }}>
          <Form onSubmit={handleSubmit(onSubmit)}>
            <FormGroup>
              <FormItem>
                <Checkbox
                  label="Concordo com os termos"
                  name="termos"
                  control={control}
                  errors={errors}
                  required
                  marginBottom={10}
                />
                <Button>Enviar</Button>
              </FormItem>
            </FormGroup>
          </Form>
        </Container>
        <Container
          style={{
            border: "1px solid black",
            borderTop: "0",
            backgroundColor: "#f5f2f0",
          }}
        >
          <Code language="javascript">
            {`import Checkbox from "@/components/Checkbox";

<Checkbox
  label="Concordo com os termos"
  name="termos"
  control={control}
  errors={errors}
  required />"`}
          </Code>
        </Container>
      </Container>
    </Container>
  );
}
