"use client"

import { useForm } from "react-hook-form";
import Container from "@/components/Container";
import Form from "@/components/Form";
import FormGroup from "@/components/FormGroup";
import FormItem from "@/components/FormItem";
import Input from "@/components/Input";
import Text from "@/components/Text";
import Code from "@/components/Code";
import MenuItems from "@/utils/menuItems";

export default function InputPage(){

  const { control, handleSubmit, formState: { errors }} = useForm();

  const onSubmit = (data) => {
    console.log(data);
  }

  return(
    <Container flexDirection="row">
      <MenuItems />
      <Container margin="1rem" flexGrow="1">
        
        {/* Seção principal */}
        <Text as="h1" margin="0">Componente Input</Text>
        <Text as="p" margin="1rem 0">O componente Input permite a renderização de campos de entrada.<br/>Tem css valid e invalid.</Text>
        <Container style={{ border: '1px solid black'}} padding=".5rem">
          <Input type="text" placeholder="Digite o seu nome" />
        </Container>
        <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
          <Code language="javascript">
{`import Input from "@/components/Input";

<Input type="text" id="nome" placeholder="Digite o seu nome" />`}
          </Code>
        </Container>

        <Text as="p" margin="1rem 0">Outro tipos são permitidos, como password e number.</Text>
        <Container style={{ border: '1px solid black'}} padding=".5rem">
          <Input type="number" placeholder="Informe um número" marginBottom=".5rem" />
          <Input type="password" placeholder="Informe uma senha" marginBottom=".5rem"/>
          <Input type="date" marginBottom=".5rem" />
          <Input type="time" marginBottom=".5rem" />
          <Input type="email" placeholder={"Informe um email"} marginBottom=".5rem" />
          
        </Container>
        <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
          <Code language="javascript">
{`import Input from "@/components/Input";

<Input type="number" placeholder="Informe um número" marginBottom=".5rem" />
<Input type="password" placeholder="Informe uma senha" marginBottom=".5rem"/>
<Input type="date" marginBottom=".5rem" />
<Input type="time" marginBottom=".5rem" />
<Input type="email" placeholder={"Informe um email"} marginBottom=".5rem" />`}
          </Code>
        </Container>


        {/* Seção customização */}
        <Text as="h2" margin="0" margin_top="1rem">Customização</Text>
        <Text as="p" margin="1rem 0">Também é possível customizar o componente input utilizando a propriedade style.</Text>
        <Container style={{ border: '1px solid black'}} padding=".5rem">
          <Input type="text" placeholder="Digite o seu nome" style={{ border: '1px blue dotted' }} />
        </Container>
        <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
          <Code language="javascript">
{`import Input from "@/components/Input";

<Input type="text" id="nome" placeholder="Digite o seu nome" style={{ border: '1px blue dotted' }} />`}
          </Code>
        </Container>
        <Text as="p" margin="1rem 0">As seguintes propridades podem ser informadas como parâmetro:</Text>
        <Container flexDirection="row" marginBottom={25}>
        <ul style={{ marginLeft: '1rem', lineHeight: '2'}}>
          <li>margin</li>
          <li>marginTop</li>
          <li>marginRight</li>
          <li>marginBottom</li>
          <li>marginLeft</li>
        </ul>
        <ul style={{ marginLeft: '3rem', lineHeight: '2'}}>
          <li>padding</li>
          <li>paddingTop</li>
          <li>paddingRight</li>
          <li>paddingBottom</li>
          <li>paddingLeft</li>  
        </ul>
        <ul style={{ marginLeft: '3rem', lineHeight: '2'}}>
          <li>style</li>
          <li>Disabled</li>
        </ul> 
        </Container>


        <Text as="p" margin="1rem 0">As seguintes propridades podem ser configuradas no arquivo de temas:</Text>
        <ul style={{ marginLeft: '1rem', lineHeight: '2'}}>
          <li>input-border</li>
          <li>focus</li>
        </ul>

        {/* Seção React Hook Form */}
        <Text as="h2" margin="0" margin_top="1rem">Compatibilidade com React Hook Form</Text>
        <Text as="p" margin="1rem 0">O componente Input é compatível com o React Hook Form. Pressione enter no input para visualizar a validação.
        <br/>Tem css invalid conforme os erros.
        </Text>
        <Container style={{ border: '1px solid black' }}>
          <Form onSubmit={handleSubmit(onSubmit)}>
            <FormGroup>
              <FormItem>
                <Input
                  type="text"
                  id="nome"
                  name="nome"
                  control={control}
                  errors={errors}
                  rules={{ 
                    required: "O nome é obrigatório",
                    minLength: {
                      value: 3,
                      message: "O nome deve ter no mínimo 3 caracteres"
                    },
                    maxLength: {
                      value: 20,
                      message: "O nome deve ter no máximo 20 caracteres"
                    }
                  }}
                  placeholder="Digite seu nome" />
              </FormItem>
            </FormGroup>
          </Form>
        </Container>        
        <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
          <Code language="javascript">
{`import Input from "@/components/Input";

<Input
  type="text"
  id="nome"
  name="nome"
  control={control}
  errors={errors}
  rules={{ 
    required: "O nome é obrigatório",
    minLength: {
      value: 3,
      message: "O nome deve ter no mínimo 3 caracteres"
    },
    maxLength: {
      value: 20,
      message: "O nome deve ter no máximo 20 caracteres"
    }
  }}
  placeholder="Digite seu nome" />`}
          </Code>
        </Container>
      </Container>
    </Container>
  )
}