"use client"

import { useForm } from "react-hook-form";
import Code from "@/components/Code";
import Container from "@/components/Container";
import Text from "@/components/Text";
import MenuItems from "@/utils/menuItems";
import Form from "@/components/Form";
import FormGroup from "@/components/FormGroup";
import FormItem from "@/components/FormItem";
import RadioGroup from "@/components/RadioGroup";
import Button from "@/components/Button";
import { useState } from "react";

export default function RadioPage() {
  const radioNums = [
    {
      id: 1,
      label: "Opção 1",
      value: "opcao1",
      radioName: "opcao",
      defaultChecked: false,
      disabled: false
    },
    {
      id: 2,
      label: "Opção 2",
      value: "opcao2",
      radioName: "opcao",
      defaultChecked: true,
      disabled: false
    },
    {
      id: 3,
      label: "Opção 3",
      value: "opcao3",
      radioName: "opcao",
      defaultChecked: false,
      disabled: true
    },
    {
      id: 4,
      label: "Opção 4",
      value: "opcao4",
      radioName: "opcao",
      defaultChecked: false,
      disabled: false
    },
  ];

  const radioNums2 = [
    {
      id: 1,
      label: "Opção 1",
      value: "opcao1",
      radioName: "opcao2",
      defaultChecked: false,
      disabled: false
    },
    {
      id: 2,
      label: "Opção 2",
      value: "opcao2",
      radioName: "opcao2",
      defaultChecked: false,
      disabled: false
    },
    {
      id: 3,
      label: "Opção 3",
      value: "opcao3",
      radioName: "opcao2",
      defaultChecked: false,
      disabled: true
    },
    {
      id: 4,
      label: "Opção 4",
      value: "opcao4",
      radioName: "opcao2",
      defaultChecked: false,
      disabled: false
    },
  ];

  const radioNums3 = [
    {
      id: 1,
      label: "Opção 1",
      value: "opcao1",
      radioName: "opcao3",
      defaultChecked: false,
      disabled: false
    },
    {
      id: 2,
      label: "Opção 2",
      value: "opcao2",
      radioName: "opcao3",
      defaultChecked: true,
      disabled: false
    },
    {
      id: 3,
      label: "Opção 3",
      value: "opcao3",
      radioName: "opcao3",
      defaultChecked: false,
      disabled: true
    },
    {
      id: 4,
      label: "Opção 4",
      value: "opcao4",
      radioName: "opcao3",
      defaultChecked: false,
      disabled: false
    },
  ];

  const [valueChecked, setValueChecked] = useState()
  const [valueChecked2, setValueChecked2] = useState()

  const {
    control,
    handleSubmit,
    formState: { errors },
  } = useForm({
    defaultValues: {
      teste: "opcao2",
    },
  });

  const onSubmit = (data) => {
    console.log(data);
  };

  return (
    <Container style={{flexDirection: "row"}}>
      <MenuItems />
      <Container margin="1rem" flexGrow="1">
        <Text as="h1" margin="0">
          Componente RadioGroup
        </Text>
        <Text as="p" margin="1rem 0">
          O componente Radio permite ao usuário seleção única. Por padrão,
          utilza a cor primária definida no tema. Por padrão fica em colunas, pode ficar em linhas se adicionado o <strong>prop row</strong>. Tem versão big e small.<br/>O exportvalue é usado para exportar o valor selecionado para um estado.
        </Text>
        <Container style={{ border: "1px solid black" }} padding=".5rem">
          <RadioGroup radioOptions={radioNums} exportValue={setValueChecked} row/>
        </Container>
        <Container
          style={{
            border: "1px solid black",
            borderTop: "0",
            backgroundColor: "#f5f2f0",
          }}
        >
          <Code language="javascript">
            {`import RadioGroup from "@/components/RadioGroup";

const [valueChecked, setValueChecked] = useState()
const radioNums = [
  {id: 1, label:"Opção 1", value:"opcao1", radioName:"opcao", defaultChecked:false, disabled: false},
  {id: 2, label:"Opção 2", value:"opcao2", radioName:"opcao", defaultChecked:true, disabled: false},
  {id: 3, label:"Opção 3", value:"opcao3", radioName:"opcao", defaultChecked:false, disabled: true},
  {id: 4, label:"Opção 4", value:"opcao4", radioName:"opcao", defaultChecked:false, disabled: false},
]

<RadioGroup radioOptions={radioNums} exportValue={setValueChecked} row/>`}
          </Code>
        </Container>


        {/* Seção customização */}
        <Text as="h2" margin="0" margin_top="1rem">Customização</Text>
        <Text as="p" margin="1rem 0">Também é possível customizar o componente input utilizando a propriedade style.</Text>
        <Container style={{ border: '1px solid black'}} padding=".5rem">
          <RadioGroup small radioOptions={radioNums2} exportValue={setValueChecked2} marginTop={50} paddingBottom={50} style={{ border: '1px blue dotted' }} />
        </Container>
        <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
          <Code language="javascript">
          {`import RadioGroup from "@components/RadioGroup"

<RadioGroup 
  small 
  radioOptions={radioNums2} 
  exportValue={setValueChecked2} 
  marginTop={50} 
  paddingBottom={50} 
  style={{ border: '1px blue dotted' }} 
/>


`}
          </Code>
        </Container>
        <Text as="p" margin="1rem 0">As seguintes propridades podem ser informadas como parâmetro:</Text>
        <Container row marginBottom={25}>
        <ul style={{ marginLeft: '1rem', lineHeight: '2'}}>
          <li>margin</li>
          <li>marginTop</li>
          <li>marginRight</li>
          <li>marginBottom</li>
          <li>marginLeft</li>
        </ul>
        <ul style={{ marginLeft: '3rem', lineHeight: '2'}}>
          <li>padding</li>
          <li>paddingTop</li>
          <li>paddingRight</li>
          <li>paddingBottom</li>
          <li>paddingLeft</li>  
        </ul>
        <ul style={{ marginLeft: '3rem', lineHeight: '2'}}>
          <li>style</li>
          <li>big</li>
          <li>small</li>
          <li>row</li>
        </ul> 
        </Container>



        {/* Seção React Hook Form */}
        <Text as="h2" margin="0" margin_top="1rem">
          Compatibilidade com React Hook Form
        </Text>
        <Text as="p" margin="1rem 0">
          O componente Input é compatível com o React Hook Form. Pressione enter
          no input para visualizar a validação.
        </Text>
        <Container style={{ border: "1px solid black" }}>
          <Form onSubmit={handleSubmit(onSubmit)}>
            <FormGroup>
              <FormItem>
                <RadioGroup
                  radioOptions={radioNums3}
                  control={control}
                  erros={errors}
                  name={"teste"}
                />
                <Button>Enviar</Button>
              </FormItem>
            </FormGroup>
          </Form>
        </Container>
        <Container
          style={{
            border: "1px solid black",
            borderTop: "0",
            backgroundColor: "#f5f2f0",
          }}
        >
          <Code language="javascript">
            {`import RadioGroup from "@/components/RadioGroup";

const { control, handleSubmit, formState: { errors }, } = useForm({ defaultValues: { teste: "opcao2", },});

const radioNums = [
  {id: 1, label:"Opção 1", value:"opcao1", radioName:"opcao", defaultChecked:false, disabled: false},
  {id: 2, label:"Opção 2", value:"opcao2", radioName:"opcao", defaultChecked:true, disabled: false},
  {id: 3, label:"Opção 3", value:"opcao3", radioName:"opcao", defaultChecked:false, disabled: true},
  {id: 4, label:"Opção 4", value:"opcao4", radioName:"opcao", defaultChecked:false, disabled: false},
]"

<RadioGroup radioOptions={radioNums} control={control} erros={errors} name={"teste"} />`}
          </Code>
        </Container>
      </Container>
    </Container>
  );
}
