"use client"

import Code from "@/components/Code";
import Container from "@/components/Container";
import Select from "@/components/Select";
import SelectSearch from "@/components/SelectSearch";
import Option from "@/components/Option";
import Text from "@/components/Text";
import MenuItems from "@/utils/menuItems";
import Form from "@/components/Form";
import FormGroup from "@/components/FormGroup";
import FormItem from "@/components/FormItem";
import { useForm } from "react-hook-form";
import Button from "@/components/Button";
import { useState } from "react";

export default function SelectPage() {
  const [valor, setValor] = useState();

  const {
    control,
    handleSubmit,
    formState: { errors },
  } = useForm({ defaultValues: { uf: "" } });

  const onSubmit = (data) => {
    console.log(data);
  };

  return (
    <Container flexDirection="row">
      <MenuItems />
      <Container margin="1rem" flexGrow="1">
        {/* Seção principal */}
        <Text as="h1" margin="0" onClick={() => console.log(valor)}>
          Componente Select
        </Text>
        <Text as="p" margin="1rem 0">
          O componente Select permite, em combinação com o componente Option,
          uma seleção única em uma caixa suspensa.<br/>
          O exportValue utilizado para "exportar" o valor para um estado, bota como argumento o set do estado.<br/>
        </Text>
        <Container style={{ border: "1px solid black" }} padding=".5rem">
          <Select id="estados" exportValue={setValor}>
            <Option value="AC">Acre</Option>
            <Option value="AM">Amazonas</Option>
            <Option value="RO">Rondônia</Option>
          </Select>
        </Container>
        <Container
          style={{
            border: "1px solid black",
            borderTop: "0",
            backgroundColor: "#f5f2f0",
          }}
        >
          <Code language="javascript">
            {`import Select from "@/components/Select
import Option from "@/components/Option

const [valor, setValor] = useState();

<Select id="estados" exportValue={setValor}>
  <Option value="AC">Acre</Option>
  <Option value="AM">Amazonas</Option>
  <Option value="RO">Rondônia</Option>
</Select>`}
          </Code>
        </Container>

        {/* Seção css valid e invalid */}
        <Text as="h2" margin="0" margin_top="1rem">
          CSS invalid e valid
        </Text>
        <Text as="p" margin="1rem 0">
          Caso tenha required como parâmetro, terá css invalid e valid.
        </Text>
        <Container style={{ border: "1px solid black" }} padding=".5rem">
          
          <Form>
            <Container flexDirection={"row"} gap={10}>
          <Select id="estados" required >
            <Option value="AC">Acre</Option>
            <Option value="AM">Amazonas</Option>
            <Option value="RO">Rondônia</Option>
          </Select>
          <Button  style={{display: "inline-block"}} >Enviar</Button>
          </Container>
          </Form>
          
        </Container>
        <Container
          style={{
            border: "1px solid black",
            borderTop: "0",
            backgroundColor: "#f5f2f0",
          }}
        >
          <Code language="javascript">
            {`import Select from "@/components/Select"
import Option from "@/components/Option"

<Select id="estados" required>
  <Option value="AC">Acre</Option>
  <Option value="AM">Amazonas</Option>
  <Option value="RO">Rondônia</Option>
</Select>`}
          </Code>
        </Container>

        {/* Seção customização */}
        <Text as="h2" margin="0" margin_top="1rem">
          Customização
        </Text>
        <Text as="p" margin="1rem 0">
          Também é possível customizar o componente input utilizando a
          propriedade style.
        </Text>
        <Container style={{ border: "1px solid black" }} padding=".5rem">
          <Select
            id="estados"
            style={{ border: "1px blue dotted" }}
            width="100px"
          >
            <Option value="AC">Acre</Option>
            <Option value="AM">Amazonas</Option>
            <Option value="RO">Rondônia</Option>
          </Select>
        </Container>
        <Container
          style={{
            border: "1px solid black",
            borderTop: "0",
            backgroundColor: "#f5f2f0",
          }}
        >
          <Code language="javascript">
            {`import Select from "@/components/Select"
import Option from "@/components/Option"

<Select id="estados" style={{ border: '1px blue dotted' }} width="100px">
  <Option value="AC">Acre</Option>
  <Option value="AM">Amazonas</Option>
  <Option value="RO">Rondônia</Option>
</Select>`}
          </Code>
        </Container>
        <Text as="p" margin="1rem 0">
          As seguintes propridades podem ser informadas como parâmetro:
        </Text>
        <Container flexDirection="row" marginBottom={25}>
        <ul style={{ marginLeft: '1rem', lineHeight: '2'}}>
          <li>margin</li>
          <li>marginTop</li>
          <li>marginRight</li>
          <li>marginBottom</li>
          <li>marginLeft</li>
        </ul>
        <ul style={{ marginLeft: '3rem', lineHeight: '2'}}>
          <li>padding</li>
          <li>paddingTop</li>
          <li>paddingRight</li>
          <li>paddingBottom</li>
          <li>paddingLeft</li>  
        </ul>
        <ul style={{ marginLeft: '3rem', lineHeight: '2'}}>
          <li>style</li>
          <li>Disabled</li>
          <li>width</li>
        </ul> 
        </Container>


        {/* React Hook Form */}
        <Text as="h2" margin="0" margin_top="1rem">
          Compatibilidade com React Hook Form
        </Text>
        <Text as="p" margin="1rem 0">
          O componente Select permite, em combinação com o componente Option,
          uma seleção única em uma caixa suspensa. Define o selected por padrão
          no DefaultValues do React Hook Form.<br/>
          Também tem css invalid e valid que depende da rules e errors.
        </Text>
        <Container style={{ border: "1px solid black" }} padding=".5rem">
          <Form>
            <FormGroup>
              <FormItem>
                <Select
                  control={control}
                  name="uf"
                  rules={{ required: "O estado é obrigatório" }}
                  errors={errors}
                >
                  <Option value="AC">Acre</Option>
                  <Option value="AM">Amazonas</Option>
                  <Option value="RO">Rondônia</Option>
                </Select>
              </FormItem>
              <FormItem>
                <Button onClick={handleSubmit(onSubmit)}>Enviar</Button>
              </FormItem>
            </FormGroup>
          </Form>
        </Container>
        <Container
          style={{
            border: "1px solid black",
            borderTop: "0",
            backgroundColor: "#f5f2f0",
          }}
        >
          <Code language="javascript">
            {`import Select from "@/components/Select";
import Option from "@/components/Option";

<Select 
  control={control}
  name="uf"
  rules={{ required: "O estado é obrigatório" }}
  errors={errors}>
  <Option value="AC">Acre</Option>
  <Option value="AM">Amazonas</Option>
  <Option value="RO">Rondônia</Option>
</Select>`}
          </Code>
        </Container>
      </Container>
    </Container>
  );
}
