"use client"

import Code from "@/components/Code";
import Container from "@/components/Container";
import Select from "@/components/Select";
import SelectSearch from "@/components/SelectSearch";
import Option from "@/components/Option";
import Text from "@/components/Text";
import MenuItems from "@/utils/menuItems";
import Form from "@/components/Form";
import FormGroup from "@/components/FormGroup";
import FormItem from "@/components/FormItem";
import { useForm } from "react-hook-form";
import Button from "@/components/Button";
import { useState } from "react";

export default function SelectPage(){

  const [valor, setValor] = useState()
  
  const { control, handleSubmit, formState: { errors }} = useForm({defaultValues : {uf : "Acre"}});

  const onSubmit = (data) => {
    console.log(data);
  };

  const options = ["About","Base","Blog","Contact","Custom","Support","Tools",]
  const opcoes = ["Sobre","Base","Blog","Contato","Customização","Suporte","Ferramentas"]
  const estados = ["Acre","Amazonas","Roraima","Rondônia", "Amapá", "Pará"]

  return(
    <Container flexDirection="row">
    <MenuItems />
    <Container margin="1rem" flexGrow="1">
      
      {/* Seção principal */}
      <Text as="h1" margin="0" onClick={()=>console.log(valor)}>Componente SelectSearch</Text>
      <Text as="p" margin="1rem 0">O componente SelectSearch é como o componente select, sua diferença sendo que recebe as opções de uma array, e que tem uma caixa de pesquisa para filtrar as opções.
      <br/>O exportValue utilizado para "exportar" o valor para um estado, bota como argumento o set do estado.
      </Text>
      <Container style={{ border: '1px solid black'}} padding=".5rem">
        <SelectSearch options={options} exportValue={setValor} defaultValue={"Base"} width={500}/>
      </Container>
      <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
        <Code language="javascript">
{`import SelectSearch from "@/components/SelectSearch

const [valor, setValor] = useState()
const options = ["About","Base","Blog","Contact","Custom","Support","Tools"]

<SelectSearch options={options} exportValue={setValor} defaultValue={"Base"}/>`}
        </Code>
      </Container>

        {/* Seção customização */}
        <Text as="h2" margin="0" margin_top="1rem">Customização</Text>
        <Text as="p" margin="1rem 0">Também é possível customizar o componente input utilizando a propriedade style.</Text>
        <Container style={{ border: '1px solid black'}} padding=".5rem">
          <SelectSearch options={opcoes} placeholder={"Selecione opção"} style={{ border: "1px blue dotted" }} width={300} marginLeft={100}/>
        </Container>
        <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
          <Code language="javascript">
{`import SelectSearch from "@/components/SelectSearch";

<SelectSearch 
  options={opcoes} 
  placeholder={"Selecione opção"} 
  style={{ border: "1px blue dotted" }} 
  width={300} 
  marginLeft={100}
/>`}
          </Code>
        </Container>
        <Text as="p" margin="1rem 0">As seguintes propridades podem ser informadas como parâmetro:</Text>
        <Container flexDirection="row" marginBottom={25}>
        <ul style={{ marginLeft: '1rem', lineHeight: '2'}}>
          <li>margin</li>
          <li>marginTop</li>
          <li>marginRight</li>
          <li>marginBottom</li>
          <li>marginLeft</li>
        </ul>
        <ul style={{ marginLeft: '3rem', lineHeight: '2'}}>
          <li>padding</li>
          <li>paddingTop</li>
          <li>paddingRight</li>
          <li>paddingBottom</li>
          <li>paddingLeft</li>  
        </ul>
        <ul style={{ marginLeft: '3rem', lineHeight: '2'}}>
          <li>style</li>
          <li>disabled</li>
          <li>width</li>
          <li>placeholder</li>
          <li>defaultValue</li>
        </ul> 
        </Container>
      {/* React Hook Form */}
      <Text as="h2" margin="0" margin_top="1rem">Compatibilidade com React Hook Form</Text>
      <Text as="p" margin="1rem 0">O componente SelectSearch permite uma seleção única em uma caixa suspensa, com uma barra para pesquisa.
       Define o selected por padrão no DefaultValues do React Hook Form.</Text>
      <Container style={{ border: '1px solid black'}} padding=".5rem">
        <Form onSubmit={handleSubmit(onSubmit)}>
          <FormGroup>
            <FormItem>
              <SelectSearch
                control={control}
                name="uf"
                // rules={{ required: "O estado é obrigatório" }}
                errors={errors}
                options={estados}>
              </SelectSearch>
            </FormItem>
            <FormItem>
              <Button >Enviar</Button>
            </FormItem>
          </FormGroup>
        </Form>
      </Container>
      <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
        <Code language="javascript">
{`import SelectSearch from "@/components/SelectSearch";
const { control, handleSubmit, formState: { errors }} = useForm({defaultValues : {uf : "Acre"}});


<SelectSearch
  control={control}
  name="uf"
  errors={errors}
  options={estados}>
</SelectSearch>`}
        </Code>
      </Container>
  

     </Container>
  </Container>
  )
}