"use client"
import Button from "@/components/Button";
import Code from "@/components/Code";
import Container from "@/components/Container";
import Form from "@/components/Form";
import FormGroup from "@/components/FormGroup";
import FormItem from "@/components/FormItem";
import Switch from "@/components/Switch";
import Text from "@/components/Text";
import MenuItems from "@/utils/menuItems";
import { useState } from "react";
import { useForm } from "react-hook-form";

export default function SwitchPage() {
  const [switchValue, setSwitchValue] = useState(true);

  const {
    control,
    handleSubmit,
    formState: { errors },
  } = useForm();


  const onSubmit = (data) => {
    console.log(data);
  };

  return (
    <Container flexDirection="row">
      <MenuItems />
      <Container margin="1rem" flexGrow="1">
        {/* Seção principal */}
        <Text
          as="h1"
          margin="0"
          onClick={() => {
            console.log(switchValue);
          }}
        >
          Componente Switch
        </Text>
        <Text as="p" margin="1rem 0">
          O componente Switch é equivalente ao componente Checkbox.
        </Text>
        <Container style={{ border: "1px solid black" }} padding=".5rem">
          <Switch checked={switchValue} exportValue={setSwitchValue}>
            Concordo
          </Switch>
        </Container>
        <Container
          style={{
            border: "1px solid black",
            borderTop: "0",
            backgroundColor: "#f5f2f0",
          }}
        >
          <Code language="javascript">
            {`import Switch from "@/components/Switch";

const [switchValue, setSwitchValue] = useState(true);

<Switch checked={switchValue} exportValue={setSwitchValue}>Concordo</Switch>`}
          </Code>
        </Container>

        {/* Seção customização */}
        <Text as="h2" margin="0" margin_top="1rem">Customização</Text>
        <Text as="p" margin="1rem 0">Também é possível customizar o componente input utilizando a propriedade style.</Text>
        <Container style={{ border: '1px solid black'}} padding=".5rem">
          <Switch small checked={switchValue} exportValue={setSwitchValue} >Concordo</Switch>
          <Switch big checked={switchValue} exportValue={setSwitchValue} marginTop={5}>Concordo</Switch>
          <Switch disabled checked={switchValue} exportValue={setSwitchValue} marginTop={5}>Concordo</Switch>
        </Container>
        <Container style={{ border: '1px solid black', borderTop: '0', backgroundColor: '#f5f2f0' }}>
          <Code language="javascript">
          {`import InputToTag from "@components/InputToTag"

//criação do estado do Switch
const [tags, setTags] = useState([]);

<Switch small checked={switchValue} exportValue={setSwitchValue} >Concordo</Switch>
<Switch big checked={switchValue} exportValue={setSwitchValue} marginTop={5}>Concordo</Switch>
<Switch disabled checked={switchValue} exportValue={setSwitchValue} marginTop={5}>Concordo</Switch>

`}
          </Code>
        </Container>
        <Text as="p" margin="1rem 0">As seguintes propridades podem ser informadas como parâmetro:</Text>
        <Container flexDirection="row" marginBottom={25}>
        <ul style={{ marginLeft: '1rem', lineHeight: '2'}}>
          <li>margin</li>
          <li>marginTop</li>
          <li>marginRight</li>
          <li>marginBottom</li>
          <li>marginLeft</li>
        </ul>
        <ul style={{ marginLeft: '3rem', lineHeight: '2'}}>
          <li>padding</li>
          <li>paddingTop</li>
          <li>paddingRight</li>
          <li>paddingBottom</li>
          <li>paddingLeft</li>  
        </ul>
        <ul style={{ marginLeft: '3rem', lineHeight: '2'}}>
          <li>style</li>
          <li>Disabled</li>
          <li>small</li>
          <li>big</li>
        </ul> 
        </Container>


        <Text as="h1" marginTop="30">
          Compatibilidade com React Hook Form
        </Text>
        <Text as="p" margin="1rem 0">
          Caso queira por padrão vir checkado, definir no defaultValue.
        </Text>
        <Container style={{ border: "1px solid black" }} padding=".5rem">
            <Form onSubmit={handleSubmit(onSubmit)}>
            <FormGroup>
              <FormItem>
                <Switch
                  name="termos"
                  control={control}
                  errors={errors}
                >
                  Concordo
                </Switch>
                {/* <Button>enviar</Button> */}
              </FormItem>
            </FormGroup>
            </Form>
        </Container>
        <Container
          style={{
            border: "1px solid black",
            borderTop: "0",
            backgroundColor: "#f5f2f0",
          }}
        >
          <Code language="javascript">
            {`import Message from "@/components/Message";

<Switch
  name="termos"
  control={control}
  errors={errors}
>
  Concordo
</Switch>`}
          </Code>
        </Container>
      </Container>
    </Container>
  );
}
