"use client"

import { useForm } from "react-hook-form";
import Container from "@/components/Container";
import Form from "@/components/Form";
import FormGroup from "@/components/FormGroup";
import FormItem from "@/components/FormItem";
import Text from "@/components/Text";
import Code from "@/components/Code";
import MenuItems from "@/utils/menuItems";
import Textarea from "@/components/Textarea";
import Button from "@/components/Button";

export default function TextareaPage() {
  const {
    control,
    handleSubmit,
    formState: { errors },
  } = useForm();

  const onSubmit = (data) => {
    console.log(data);
  };

  return (
    <Container flexDirection="row">
      <MenuItems />
      <Container margin="1rem" flexGrow="1">
        {/* Seção principal */}
        <Text as="h1" margin="0">
          Componente Textarea
        </Text>
        <Text as="p" margin="1rem 0">
          O componente Textarea permite a renderização de campos de entrada com
          mais espaço de texto.
        </Text>
        <Container style={{ border: "1px solid black" }} padding=".5rem">
          <Textarea placeholder="Informe as observações"></Textarea>
        </Container>
        <Container
          style={{
            border: "1px solid black",
            borderTop: "0",
            backgroundColor: "#f5f2f0",
          }}
        >
          <Code language="javascript">
            {`import Textarea from "@/components/Textarea";

<Textarea placeholder="Informe as observações"></Textarea>`}
          </Code>
        </Container>

        <Text as="p" margin="1rem 0">
          Tem css valid e invalid caso tenha a propriedade required.
        </Text>
        <Container style={{ border: "1px solid black" }} padding=".5rem">
          <form>
            <Textarea required placeholder="Informe as observações"></Textarea>
            <Button>Enviar</Button>
          </form>
        </Container>
        <Container
          style={{
            border: "1px solid black",
            borderTop: "0",
            backgroundColor: "#f5f2f0",
          }}
        >
          <Code language="javascript">
            {`import Textarea from "@/components/Textarea";

<Textarea required placeholder="Informe as observações"></Textarea>`}
          </Code>
        </Container>

        <Text as="p" margin="1rem 0">
          Exemplo do componente Textarea com a propriedade disabled.
        </Text>
        <Container style={{ border: "1px solid black" }} padding=".5rem">
          <Textarea placeholder="Informe as observações" disabled></Textarea>
        </Container>
        <Container
          style={{
            border: "1px solid black",
            borderTop: "0",
            backgroundColor: "#f5f2f0",
          }}
        >
          <Code language="javascript">
            {`import Textarea from "@/components/Textarea";

<Textarea placeholder="Informe as observações" disabled></Textarea>`}
          </Code>
        </Container>

        {/* Seção customização */}
        <Text as="h2" margin="0" margin_top="1rem">
          Customização
        </Text>
        <Text as="p" margin="1rem 0">
          Também é possível customizar o componente Textarea utilizando a
          propriedade style.
        </Text>
        <Container style={{ border: "1px solid black" }} padding=".5rem">
          <Textarea
            type="text"
            placeholder="Informe as observações"
            style={{ border: "1px blue dotted" }}
            height="100px"
          ></Textarea>
        </Container>
        <Container
          style={{
            border: "1px solid black",
            borderTop: "0",
            backgroundColor: "#f5f2f0",
          }}
        >
          <Code language="javascript">
            {`import Input from "@/components/Input";

<Textarea type="text" id="nome" placeholder="Informe as observações" style={{ border: '1px blue dotted' }} height="100px"></Textarea>`}
          </Code>
        </Container>
        <Text as="p" margin="1rem 0">
          As seguintes propridades podem ser informadas como parâmetro:
        </Text>
        <Container flexDirection="row" marginBottom={25}>
          <ul style={{ marginLeft: "1rem", lineHeight: "2" }}>
            <li>margin</li>
            <li>marginTop</li>
            <li>marginRight</li>
            <li>marginBottom</li>
            <li>marginLeft</li>
          </ul>
          <ul style={{ marginLeft: "3rem", lineHeight: "2" }}>
            <li>padding</li>
            <li>paddingTop</li>
            <li>paddingRight</li>
            <li>paddingBottom</li>
            <li>paddingLeft</li>
          </ul>
          <ul style={{ marginLeft: "3rem", lineHeight: "2" }}>
            <li>style</li>
            <li>Disabled</li>
            <li>height</li>
          </ul>
        </Container>

        <Text as="p" margin="1rem 0">
          As seguintes propridades podem ser configuradas no arquivo de temas:
        </Text>
        <ul style={{ marginLeft: "1rem", lineHeight: "2" }}>
          <li>textarea-border</li>
          <li>focus</li>
        </ul>

        {/* Seção React Hook Form */}
        <Text as="h2" margin="0" margin_top="1rem">
          Compatibilidade com React Hook Form
        </Text>
        <Text as="p" margin="1rem 0">
          O componente Textarea é compatível com o React Hook Form.<br/>Tem css valid e invalid conforme os errors
        </Text>
        <Container style={{ border: "1px solid black" }}>
          <Form onSubmit={handleSubmit(onSubmit)}>
            <FormGroup>
              <FormItem>
                <Textarea
                  id="observacoes"
                  name="observacoes"
                  control={control}
                  errors={errors}
                  rules={{
                    required: "É obrigatório alguma observação",
                    minLength: {
                      value: 3,
                      message: "A observação ter no mínimo 3 caracteres",
                    },
                    maxLength: {
                      value: 20,
                      message: "A observação deve ter no máximo 20 caracteres",
                    },
                  }}
                  placeholder="Informe as observações"
                ></Textarea>
                <Button margin_top={20}>Enviar</Button>
              </FormItem>
            </FormGroup>
          </Form>
        </Container>
        <Container
          style={{
            border: "1px solid black",
            borderTop: "0",
            backgroundColor: "#f5f2f0",
          }}
        >
          <Code language="javascript">
            {`import Textarea from "@/components/Textarea";

<Textarea
  id="observacoes"
  name="observacoes"
  control={control}
  errors={errors}
  rules={{ 
    required: "É obrigatório alguma onservação",
    minLength: {
      value: 3,
      message: "A observação ter no mínimo 3 caracteres"
    },
    maxLength: {
      value: 20,
      message: "A observação deve ter no máximo 20 caracteres"
    }
  }}
  placeholder="Informe as observações"></Textarea>`}
          </Code>
        </Container>
      </Container>
    </Container>
  );
}
