import { useEffect, useState } from 'react';
import styles from './styles.module.scss';
import classNames from 'classnames';

export default function Alert({ message, duration = 3000, 
  topRight, topLeft, bottomRight, bottomLeft, ...props }){

  const [showAlert, setShowAlert] = useState(true);
  const [progress, setProgress] = useState(0);

  useEffect(() => {
    const timer = setInterval(() => {
      setProgress((prevProgress) => {
        if (prevProgress >= 100) {
          clearInterval(timer);
          setShowAlert(false);
        }
        return prevProgress + (100 / duration) * 1000;
      });
    }, 1000);

    return () => {
      clearInterval(timer);
    };
  }, [duration]);

  if (!showAlert) {
    return null;
  }

  const allStyle = classNames(styles.alert, {
    [styles.alert]: true,
    [styles.topRight]: topRight,
    [styles.topLeft]: topLeft,
    [styles.bottomRight]: bottomRight,
    [styles.bottomLeft]: bottomLeft,
    [styles.info]: props.info,
    [styles.danger]: props.danger,
    [styles.success]: props.success,
    [styles.warning]: props.warning,
  });

  return (
    <div className={allStyle}>
      <span className={styles.alertMessage}>{message}</span>
      <div className={styles.progressBarContainer}>
        <div
          className={styles.progressBar}
          style={{ width: `${progress}%` }}
        ></div>
      </div>
    </div>
  );
}