import { useState, useEffect } from "react";
import { Controller, useForm} from 'react-hook-form';
import styles from "./styles.module.scss";
import classNames from "classnames";

export default function Checkbox({
  margin,
  marginTop,
  marginRight,
  marginLeft,
  marginBottom,
  name,
  control,
  errors,
  rules,
  padding,
  paddingBottom,
  paddingLeft,
  paddingRight,
  paddingTop,
  checked,
  label,
  disabled,
  style,
  exportValue,
  ...props
}) {
  const [isChecked, setIsChecked] = useState(true);

  useEffect(() => {
    if (checked) {
      setIsChecked(false);
    }
  }, [checked]);

  const { register } = useForm({ defaultValues: { check: checked } });

  const classes = classNames({
    [styles.checkbox]: true,
    [styles.checkboxDisabled]: disabled,
    [styles.big]: props.big,
    [styles.small]: props.small,
  });

  const allStyle = {
    ...(margin && { margin }),
    ...(marginTop && { marginTop: marginTop }),
    ...(marginBottom && { marginBottom: marginBottom }),
    ...(marginLeft && { marginLeft: marginLeft }),
    ...(marginRight && { marginRight: marginRight }),
    ...(padding && { padding }),
    ...(paddingTop && { paddingTop: paddingTop }),
    ...(paddingBottom && { paddingBottom: paddingBottom }),
    ...(paddingLeft && { paddingLeft: paddingLeft }),
    ...(paddingRight && { paddingRight: paddingRight }),
    ...(style && style),
  };

  if (!control) {
    return (
      <div style={allStyle}>
      <label className={classes}>
        <input
          type="checkbox"
          onChange={(e) => {
            setIsChecked(!e.target.checked);
            if(exportValue) exportValue(isChecked);
            //console.log(isChecked);
          }}
          checked={!isChecked}
          disabled={disabled}
          {...props}
        />
        <span className={styles.checkmark}></span>
        <span>{label}</span>
      </label>
      </div>
    );
  } else {
    return (
      <>
        <label className={classes} style={allStyle}>
          <Controller
            name={name}
            control={control}
            defaultValue={false}
            render={({ field }) => (
              <input
                type="checkbox"
                checked={field.checked}
                {...register("check")}
                onChange={(e) => {
                  field.onChange(e.target.checked);
                  console.log(e.target.checked);
                }}
                disabled={disabled}
                {...props}
              />
            )}
          />
          <span className={styles.checkmark}></span>
          <span>{label}</span>
        </label>
        {errors[name] && <span>{errors[name].message}</span>}
      </>
    );
  }
};
