import styles from './styles.module.scss';
import classNames from 'classnames';
import { Controller } from 'react-hook-form';
import { forwardRef } from 'react';

function Input({ margin, marginTop, marginRight, marginLeft, marginBottom,
  name, control, errors, rules, mask,
  style, type, placeholder, ...props }, ref) {

  const classes = classNames({
    [styles.input]: true,
    [styles.info]: props.info,
    [styles.danger]: props.danger,
    [styles.success]: props.success,
    [styles.warning]: props.warning
  });

  const allStyle = {
    ...(margin && { margin }),
    ...(marginTop && { marginTop: marginTop }),
    ...(marginBottom && { marginBottom: marginBottom }),
    ...(marginLeft && { marginLeft: marginLeft }),
    ...(marginRight && { marginRight: marginRight }),
    ...(style && style)
  };

  if (!control) {
    return (
      <input
        className={classes}
        style={allStyle}
        placeholder={placeholder}
        type={type}
        {...props} ref={ref} />);
  } else if (control && mask) {
    return (
      <>
        <Controller
          control={control}
          name={name}
          rules={rules}
          render={({ field }) =>
            <input {...field}
              className={classes}
              style={allStyle}
              type={type}
              value={field.value || ""}
              onChange={(e) => {
                let valueMask = mask(e.target.value)
                field.onChange(valueMask)
              }}
              placeholder={placeholder}
              {...props} ref={ref} />}
        />
        {errors[name] && <span className={styles.errorMessage}>{errors[name].message}</span>}
      </>
    );
  } else {
    return (
      <>
        <Controller
          control={control}
          name={name}
          rules={rules}
          render={({ field }) =>
            <input {...field}
              className={classes}
              style={allStyle}
              type={type}
              checked={field.value}
              value={field.value || ""}
              placeholder={placeholder}
              {...props} ref={ref} />}
        />
        {errors[name] && <span className={styles.errorMessage}>{errors[name].message}</span>}
      </>
    );
  }
}

export default forwardRef(Input);
