"use client"

import Image from 'next/image';
import Link from 'next/link';
import { useEffect, useState } from 'react';
import styles from './styles.module.css';

export default function PaginationNextRouter({ maxPageComponent = 5, totalPages, currentPage, querys, linkPagina, wordPage }) {

  // Atenção: este componente só irá funcionar se for utilizado com o framework Next.JS e o uso do hook useRouter.

  // o proprósito deste componente é gerar links para as páginas próxima páginas e suas devidas querys, por exemplo:

  // /usuarios?page=1&nome=JhonDoe&email=jhondoe@gmail.com

  /* Exemplo de uso do componente PaginationNextRouter

   Antes instancie o router no topo da página que você estiver

   let router = (); Next com pasta pages
   searchParams -> Next 13 em diante

   {pessoas.length > 0 && (
     <Pagination
       currentPage={router.query.page}
       maxPageComponent={7}
       totalPages={totalPaginas}
       querys={router.query}
       linkPagina={"/pessoas/listar"}
     />
   )}
  */

  // geralmente essas informações que é passada como propriedade para o componente é gerado pela API que estiver utilizando.

  // O que é cada propriedade:

  // currentPage -> pagina atual 
  // totalPages -> total de páginas 
  // maxPageComponent -> quantidade de página que será mostrada no componente, por padrão já é 5, se quiser aumentar ou diminuir passe somente números ímpares.
  // querys -> recebe as querys da página que vem como um objeto, que é a forma que o userRouter() lida com isso
  // linkPagina -> é o link da página que você estiver, é importante para lidar com as querys, ex: /pessoas/listar etc...
 
  const [pagination, setPagination] = useState();
  
  // função que faz a paginação
  function PaginationFunction(maxPageComponent, currentPage, totalPages, linkPagina) {
    let pages = [];
    let metade = Math.floor(maxPageComponent / 2);
    let pinicio = parseInt(currentPage) - metade;
    let pfim = parseInt(currentPage) + metade;

    // inicio menor ou igual a zero, deslocar pra direita
    if (pinicio <= 0) {
      pfim += 1 - pinicio;
      pinicio = 1;
    }

    if (pfim > totalPages) {
      pinicio += totalPages - pfim;
      pfim = totalPages;
    }

    for (let i = pinicio; i <= pfim; i++) {
      if (i <= 0 || i > totalPages) continue;

      let atual = currentPage == i ? true : false
      
      let link = gerarLink(linkPagina, querys, i);

      pages.push({ id: i, page: i, active: atual, link: link });
    }

    return pages;
  }
  
  function gerarLink(linkPagina, querys, page) {
    let link = linkPagina;

    if (page) querys = { ...querys, ...{ [wordPage]: page } }

    for (let query in querys) {
      if (!querys[query]) continue;

      if (!link.includes("?")) {
        link = link + `?${query}=${encodeURIComponent(querys[query])}`
      } else {
        link = link + `&${query}=${encodeURIComponent(querys[query])}`
      }
    }
    return link;
  }

  useEffect(() => {
    setPagination(PaginationFunction(maxPageComponent, currentPage, totalPages, linkPagina))
  }, [querys, currentPage, totalPages])

  function encontrarNumero(numero) {
    if (pagination.find(n => n.page === numero)) return true;

    return false;
  }

  if (pagination) return (
    <ul className={styles.containerPagination}>
      <li className={`${currentPage == 1 && styles.disabled}`}>
        <Link
          href={gerarLink(linkPagina, querys, Number(currentPage) - 1)}
          title='Página anterior' className={styles.iconItem}>
          <Image
            width={24}
            height={24}
            alt="Pagina Anterior"
            src={require("./arrow-left.svg")}
            style={{ cursor: "pointer", opacity: currentPage == 1 ? 0.5 : 1 }}
          />
        </Link>
      </li>

      {!encontrarNumero(1) && (
        <li>
          <Link
            href={gerarLink(linkPagina, querys, 1)}
            className={`${styles.pageItem}`}
            title={`Ir para a página 1`}>
            1
          </Link>
        </li>
      )}

      {!pagination.find((page) => page.page - 1 == 1) && pagination.length >= maxPageComponent && (
        <li className={styles.containerDot}>
          <p className={styles.dot}>...</p>
        </li>
      )}

      {pagination.map(page => (
        <li key={page.id}>
          <Link
            href={page.link}
            className={`${styles.pageItem} ${page.page == currentPage ? styles.active : ''}`}
            title={`Ir para a página ${page.page}`}>
            {page.page}
          </Link>
        </li>
      ))}

      {!pagination.find((page) => page.page + 1 == totalPages) && pagination.length >= maxPageComponent && (
        <li className={styles.containerDot}>
          <p className={styles.dot}>...</p>
        </li>
      )}

      {!encontrarNumero(totalPages) && (
        <li>
          <Link
            href={gerarLink(linkPagina, querys, totalPages)}
            className={`${styles.pageItem}`}
            title={`Ir para última página`}>
            {totalPages}
          </Link>
        </li>
      )}

      <li className={`${currentPage == totalPages && styles.disabled}`}>
        <Link
          href={gerarLink(linkPagina, querys, Number(currentPage) + 1)}
          title='Próxima página' className={styles.iconItem}>
          <Image
            src={require("./arrow-right.svg")}
            width={24}
            height={24}
            alt="Próxima página"
            style={{ cursor: "pointer", opacity: currentPage == totalPages ? 0.5 : 1 }}
          />
        </Link>
      </li>
    </ul>
  );
};
