import { Controller, useForm } from 'react-hook-form';
import styles from "./styles.module.scss";
import { useEffect, useState } from 'react';

export default function Radio({ margin, marginTop, marginRight, marginLeft, marginBottom, 
  name, errors, rules,
  checked, label, value, control, defaultValue,
  style, ...props }) {

  const allStyle = {
    ...(margin && { margin }),
    ...(marginTop && { marginTop: marginTop }),
    ...(marginBottom && { marginBottom: marginBottom }),
    ...(marginLeft && { marginLeft: marginLeft }),
    ...(marginRight && { marginRight: marginRight }),
    ...(style && style)
  };

  const [isChecked, setIsChecked] = useState(checked ? true : false)
  const {register} = useForm({ defaultValues: {check: checked} });



  if(!control){
  return (

    <>
    <label className={styles.radio}>
      <input
      type='radio'
      name={name}
      value={value}
      {...props}
      />
      <span className={styles.checkmark}></span>
      <span className={styles.label}>{label}</span>
    </label>
    </>
  );}else{
    return(
    <>
      <label className={styles.radio}>
        <Controller
          name={name}
          control={control}
          defaultValue={defaultValue}
          render={({ field }) => (
            <input
              type="radio"
              name={name}
              value={value}
              checked={field.checked}
              {...register('check')}
              onChange={(e) => {
                field.onChange(e.target.checked);
              }}
            />
          )}
        />
        <span className={styles.checkmark}></span>
        <span className={styles.label}>{label}</span>
      </label>
      {errors && errors[name] && <span>{errors[name].message}</span>}
    </>
    )
  }
};