import { Controller } from "react-hook-form";
import styles from "./styles.module.scss";
import { useEffect, useState } from "react";
import classNames from "classnames";

export default function RadioGroup({
  margin,
  marginTop,
  marginRight,
  marginLeft,
  marginBottom,
  padding,
  paddingTop,
  paddingRight,
  paddingLeft,
  paddingBottom,
  errors,
  rules,
  name,
  value,
  control,
  radioOptions,
  style,
  exportValue,
  row,
  ...props
}) {
  const allStyle = {
    ...(margin && { margin }),
    ...(marginTop && { marginTop: marginTop }),
    ...(marginBottom && { marginBottom: marginBottom }),
    ...(marginLeft && { marginLeft: marginLeft }),
    ...(marginRight && { marginRight: marginRight }),
    ...(padding && { padding }),
    ...(paddingTop && { paddingTop: paddingTop }),
    ...(paddingBottom && { paddingBottom: paddingBottom }),
    ...(paddingLeft && { paddingLeft: paddingLeft }),
    ...(paddingRight && { paddingRight: paddingRight }),
    ...(style && style),
  };

  const classes = classNames({
    [styles.big]: props.big,
    [styles.small]: props.small,
  });

  const [radioChecked, setRadioChecked] = useState();

  useEffect(() => {
    radioOptions.forEach((option) => {
      if (option.defaultChecked) {
        setRadioChecked(option.value);
      }
    });
  }, []);

  if (!control) {
    return (
      <div className={row ? styles.radioContainerRow : styles.radioContainer} style={allStyle}>
        {radioOptions.map((option, index) => (
          <label key={option.value} className={`${styles.radio} ${classes}`}>
            <input
              type="radio"
              name={option.radioName}
              value={value}
              onClick={() => {
                setRadioChecked(option.value);
                if(exportValue) exportValue(option.value)
              }}
              checked={option.value === radioChecked}
              disabled={option.disabled}
            />
            <span className={option.disabled ? styles.checkmarkDisabled : styles.checkmark}></span>
            <span className={option.disabled ? styles.labelDisabled : styles.label}>{option.label}</span>
          </label>
        ))}
      </div>
    );
  } else {
    return (
      <>
        <div className={styles.radioContainer} style={allStyle}>
          <Controller
            name={name}
            control={control}
            render={({ field }) => (
              <div className={row ? styles.radioContainerRow : null}>
                {radioOptions.map((option, index) => (
                  <label key={option.value} className={`${styles.radio} ${classes}`}>
                    <input
                      type="radio"
                      name={option.radioName}
                      value={option.value}
                      onClick={(e) => {
                        field.onChange(e.target.value);
                      }}
                      defaultChecked={option.value == radioChecked}
                      disabled={option.disabled}
                    />
                    <span className={option.disabled ? styles.checkmarkDisabled : styles.checkmark}></span>
                    <span className={option.disabled ? styles.labelDisabled : styles.label}>{option.label}</span>
                  </label>
                ))}
              </div>
            )}
          />
        </div>
        {errors && errors[name] && <span>{errors[name].message}</span>}
      </>
    );
  }
}
