"use client"

import { Controller } from "react-hook-form";
import styles from "./styles.module.scss";
import classNames from "classnames";
import { useState, useEffect } from "react";

export default function SelectSearch({
  margin,
  marginTop,
  marginRight,
  marginLeft,
  marginBottom,
  padding,
  paddingTop,
  paddingLeft,
  paddingBottom,
  paddingRight,
  exportValue,
  placeholder,
  defaultValue,
  options,
  width,
  children,
  style,
  control,
  name,
  rules,
  errors,
  ...props
}) {
  const classes = classNames({
    [styles.select]: true,
    [styles.info]: props.info,
    [styles.danger]: props.danger,
    [styles.success]: props.success,
    [styles.warning]: props.warning,
  });

  const buttonStyle = {
    ...(style && style),
  };

  const containerStyle = {
    ...(margin && { margin }),
    ...(marginTop && { marginTop: marginTop }),
    ...(marginBottom && { marginBottom: marginBottom }),
    ...(marginLeft && { marginLeft: marginLeft }),
    ...(marginRight && { marginRight: marginRight }),
    ...(padding && { padding }),
    ...(paddingTop && { paddingTop: paddingTop }),
    ...(paddingBottom && { paddingBottom: paddingBottom }),
    ...(paddingLeft && { paddingLeft: paddingLeft }),
    ...(paddingRight && { paddingRight: paddingRight }),
    ...(width && { width: width })
  }

  const [showDropDown, setShowDropDown] = useState(false);
  const [optionSelected, setOptionSelected] = useState(null);
  const [inputValue, setInputValue] = useState("");

  function selecionar(option) {
    setOptionSelected(option);
    setShowDropDown(false);
    if(exportValue) exportValue(option)
  }

  useEffect(() => {
    if(defaultValue) selecionar(defaultValue)
  }, []);

  if (!control) {
    return (
      <div className={styles.selectContainer} style={containerStyle}>
        <button
          className={classes}
          onClick={() => {
            setShowDropDown(!showDropDown);
          }}
          style={buttonStyle}
          
        >{optionSelected == null ? placeholder : null}
          {optionSelected}
          <div className={showDropDown ? styles.none : null}>&#10095;</div>
        </button>
        <div className={styles.dropDownContainer}>
          <div
            className={`${styles.dropDownContent} ${
              showDropDown ? null : styles.none
            }`}
          >
            <input
              type="text"
              placeholder="Pesquise..."
              className={styles.search}
              onChange={(e) => {
                setInputValue(e.target.value);
              }}
            />
            {options.map((option, index) => {
              if (
                option.toUpperCase().includes(inputValue.toUpperCase()) ||
                inputValue == ""
              ) {
                return <a key={option+index} onClick={() => selecionar(option)}>{option}</a>;
              }
            })}
          </div>
        </div>
      </div>
    );
  } else {
    //setOptionSelected(field.uf)

    return (
      <>
        <Controller
          control={control}
          name={name}
          rules={rules}
          render={({ field }) => (
            <div className={styles.selectContainer} style={containerStyle}>
              <div
                className={classes}
                onClick={() => {
                  setShowDropDown(!showDropDown);
                }}
                style={buttonStyle}
              >
                {field.value}
                <div className={showDropDown ? styles.none : null}>
                  &#10095;
                </div>
              </div>
              <div className={styles.dropDownContainer}>
                <div
                  className={`${styles.dropDownContent} ${
                    showDropDown ? null : styles.none
                  }`}
                >
                  <input
                    type="text"
                    placeholder="Pesquise..."
                    className={styles.search}
                    onChange={(e) => {
                      setInputValue(e.target.value);
                    }}
                  />
                  {options?.map((option, index) => {
                    if (
                      option.toUpperCase().includes(inputValue.toUpperCase()) ||
                      inputValue == ""
                    ) {
                      return (
                        <a
                          key={option+index}
                          name={option}
                          value={option}
                          onClick={(e) => {
                            selecionar(option)
                            field.onChange(e.target.name)
                            //console.log(field.value)
                          }}
                        >
                          {option}
                        </a>
                      );
                    }
                  })}
                </div>
              </div>
            </div>
          )}
        />
        {errors[name] && (
          <span className={styles.errorMessage}>{errors[name].message}</span>
        )}
      </>
    );
  }
}
