import { Children, useEffect, useState } from "react";
import styles from "./styles.module.scss";
import classNames from "classnames";
import { Controller, useForm } from "react-hook-form";

export default function Switch({
  children,
  disabled,
  checked,
  exportValue,
  big,
  small,
  margin,
  marginBottom,
  marginLeft,
  marginRight,
  marginTop,
  padding,
  paddingBottom,
  paddingLeft,
  paddingRight,
  paddingTop,
  style,
  control,
  errors,
  name,
  ...props
}) {
  
    const classes = classNames({
    [styles.switch]: true,
    [styles.disabled]: disabled,
    [styles.small]: small,
    [styles.big]: big,
  });

  const allStyle = {
    ...(margin && { margin }),
    ...(marginTop && { marginTop: marginTop }),
    ...(marginBottom && { marginBottom: marginBottom }),
    ...(marginLeft && { marginLeft: marginLeft }),
    ...(marginRight && { marginRight: marginRight }),
    ...(padding && { padding }),
    ...(paddingTop && { paddingTop: paddingTop }),
    ...(paddingBottom && { paddingBottom: paddingBottom }),
    ...(paddingLeft && { paddingLeft: paddingLeft }),
    ...(paddingRight && { paddingRight: paddingRight }),
    ...(style && style),
  };

  const { register } = useForm({ defaultValues: { check: checked } });

  const [isChecked, setIsChecked] = useState(true);

  useEffect(() => {
    if (checked) setIsChecked(false);
  }, [checked]);

  if (!control) {
    return (
      <>
        <div className={styles.container} style={allStyle}>
          <label className={classes} {...props}>
            <input
              type="checkbox"
              className={styles.slider}
              checked={!isChecked}
              disabled={disabled}
              onChange={(e) => {
                setIsChecked(!e.target.checked);
                exportValue(isChecked);
              }}
            />
            <span className={styles.slider} />
          </label>
          <label
            className={styles.label}
            //onClick={() => console.log(isChecked)}
          >
            {children}
          </label>
        </div>
      </>
    );
  } else {
    return (
      <div className={styles.container} style={allStyle}>
        <Controller
          name={name}
          control={control}
          defaultValue={false}
          render={({ field }) => (
            <>
              <label className={classes} {...props}>
                <input
                  type="checkbox"
                  className={styles.slider}
                  checked={field.checked}
                  {...register("check")}
                  disabled={disabled}
                  onChange={(e) => {
                    field.onChange(e.target.checked);
                  console.log(e.target.checked);
                  }}
                />
                <span className={styles.slider} />
              </label>
              <label
                className={styles.label}
                onClick={() => console.log(isChecked)}
              >
                {children}
              </label>
              {errors[name] && <span>{errors[name].message}</span>}
            </>
          )}
        />
      </div>
    );
  }
}
