import { Controller } from 'react-hook-form';
import styles from './styles.module.scss';
import classNames from 'classnames';

export default function Textarea({ margin, marginTop, marginRight, marginLeft, marginBottom, 
  name, control, errors, rules, padding, paddingTop, paddingRight, paddingBottom, paddingLeft,
  style, height, placeholder, children, ...props }) {
  
  const classes = classNames({
    [styles.textarea]: true,
    [styles.textareaValidation]: props.required,  
    [styles.info]: props.info,
    [styles.danger]: props.danger,
    [styles.success]: props.success,
    [styles.warning]: props.warning
  });
  
  const allStyle = {
    ...(margin && { margin }),
    ...(marginTop && { marginTop: marginTop }),
    ...(marginBottom && { marginBottom: marginBottom }),
    ...(marginLeft && { marginLeft: marginLeft }),
    ...(marginRight && { marginRight: marginRight }),
    ...(padding && { padding }),
    ...(paddingTop && { paddingTop: paddingTop }),
    ...(paddingBottom && { paddingBottom: paddingBottom }),
    ...(paddingLeft && { paddingLeft: paddingLeft }),
    ...(paddingRight && { paddingRight: paddingRight }),
    ...(height && { height: height }),
    ...(style && style)
  };
  
  if (!control) {
    return (
      <textarea 
        className={classes} 
        style={allStyle} 
        placeholder={placeholder} 
        {...props}>{children}</textarea>);
  } else {
    return (
      <>
        <Controller
          control={control}
          name={name}
          rules={rules}
          render={({ field }) => 
            <textarea{...field} 
              className={`${classes} ${rules ? (errors[name] ? styles.danger : styles.success) : null}`} 
              style={allStyle} 
              placeholder={placeholder}
              {...props}>{children}</textarea>}
              />
        {errors[name] && <span className={styles.errorMessage}>{errors[name].message}</span>}
      </>
    );
  }
}